@@ -222,8 +222,8 @@ def test_open_multiple_resolution():
     )
     assert isinstance(rds_list, list)
     assert len(rds_list) == 2
-    assert rds_list[0].dims == {"y": 1200, "x": 1200, "band": 1}
-    assert rds_list[1].dims == {"y": 2400, "x": 2400, "band": 1}
+    assert rds_list[0].sizes == {"y": 1200, "x": 1200, "band": 1}
+    assert rds_list[1].sizes == {"y": 2400, "x": 2400, "band": 1}
     for rds in rds_list:
         assert rds.attrs["SHORTNAME"] == "MOD09GA"
         rds.close()
@@ -483,12 +483,16 @@ def test_utm():
             assert "y" not in rioda.coords
 
 
-def test_band_as_variable(open_rasterio, tmp_path):
+@pytest.mark.parametrize("chunks", [True, None])
+def test_band_as_variable(open_rasterio, chunks, tmp_path):
     test_raster = tmp_path / "test.tif"
 
     with create_tmp_geotiff() as (tmp_file, expected):
         with open_rasterio(
-            tmp_file, band_as_variable=True, mask_and_scale=False
+            tmp_file,
+            band_as_variable=True,
+            mask_and_scale=False,
+            chunks=chunks,
         ) as riods:
 
             def _check_raster(raster_ds):
@@ -515,7 +519,10 @@ def test_band_as_variable(open_rasterio, tmp_path):
             # test roundtrip
             riods.rio.to_raster(test_raster)
             with open_rasterio(
-                test_raster, band_as_variable=True, mask_and_scale=False
+                test_raster,
+                band_as_variable=True,
+                mask_and_scale=False,
+                chunks=chunks,
             ) as riods_round:
                 _check_raster(riods_round)
 
@@ -1218,7 +1225,7 @@ def test_notgeoreferenced_warning(open_rasterio):
 )
 def test_nc_attr_loading(open_rasterio):
     with open_rasterio(os.path.join(TEST_INPUT_DATA_DIR, "PLANET_SCOPE_3D.nc")) as rds:
-        assert rds.dims == {"y": 10, "x": 10, "time": 2}
+        assert rds.sizes == {"y": 10, "x": 10, "time": 2}
         assert rds.attrs == {"coordinates": "spatial_ref"}
         assert rds.y.attrs["units"] == "metre"
         assert rds.x.attrs["units"] == "metre"
@@ -1234,7 +1241,7 @@ def test_nc_attr_loading__disable_decode_times(open_rasterio):
     with open_rasterio(
         os.path.join(TEST_INPUT_DATA_DIR, "PLANET_SCOPE_3D.nc"), decode_times=False
     ) as rds:
-        assert rds.dims == {"y": 10, "x": 10, "time": 2}
+        assert rds.sizes == {"y": 10, "x": 10, "time": 2}
         assert rds.attrs == {"coordinates": "spatial_ref"}
         assert rds.y.attrs["units"] == "metre"
         assert rds.x.attrs["units"] == "metre"
@@ -1459,6 +1466,34 @@ def test_writing_gcps(tmp_path):
         _check_rio_gcps(darr, *gdal_gcps)
 
 
+def test_writing_gcps__to_netcdf(tmp_path):
+    """
+    Test writing gcps to a netCDF file.
+    """
+    tiffname = tmp_path / "test.tif"
+    nc_name = tmp_path / "test_written.nc"
+
+    src_gcps, crs = _create_gdal_gcps()
+
+    with rasterio.open(
+        tiffname,
+        mode="w",
+        height=800,
+        width=800,
+        count=3,
+        dtype=numpy.uint8,
+        driver="GTiff",
+    ) as source:
+        source.gcps = (src_gcps, crs)
+
+    with rioxarray.open_rasterio(tiffname) as darr:
+        darr.to_netcdf(nc_name)
+
+    with xarray.open_dataset(nc_name, decode_coords="all") as darr:
+        assert "gcps" in darr.coords["spatial_ref"].attrs
+        _check_rio_gcps(darr, src_gcps=src_gcps, crs=crs)
+
+
 def test_read_file_handle_with_dask():
     with open(
         os.path.join(TEST_COMPARE_DATA_DIR, "small_dem_3m_merged.tif"), "rb"
